@@ -39,7 +39,7 @@ use PPIx::QuoteLike::Utils qw{
 };
 use Scalar::Util ();
 
-our $VERSION = '0.019_01';
+our $VERSION = '0.020_01';
 
 use constant CLASS_CONTROL       => 'PPIx::QuoteLike::Token::Control';
 use constant CLASS_DELIMITER     => 'PPIx::QuoteLike::Token::Delimiter';
@@ -735,12 +735,15 @@ sub __decode {
 		}
 	    }
 
+	    my @arg;
+
 	    if ( $self->postderef()
 		    and defined( my $deref = _match_postderef( $_[2] ) ) ) {
 		$interp .= $deref;
+		push @arg, postderef => 1;
 	    }
 
-	    return [ CLASS_INTERPOLATION, $interp ];
+	    return [ CLASS_INTERPOLATION, $interp, @arg ];
 	}
 
 	my $code;
